@@ -12,52 +12,67 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.8',
  'BLDLIBRARY': '-L. -lpython3.8',
- 'BLDSHARED': 'gcc -pthread -shared',
+ 'BLDSHARED': 'gcc -shared -Wl,--as-needed '
+              '-specs=/usr/lib/rpm/aurora/pie-pic-ld -Wl,-z,relro,-z,now '
+              '-Wl,--as-needed -specs=/usr/lib/rpm/aurora/pie-pic-ld '
+              '-Wl,-z,relro,-z,now',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'armv7l-unknown-linux-gnueabihf',
+ 'BUILD_GNU_TYPE': 'armv7l-unknown-linux-gnueabi',
  'BYTESTR_DEPS': '\\',
- 'CC': 'gcc -pthread',
+ 'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -g -pipe -Wall '
-           '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector-strong '
-           '--param=ssp-buffer-size=4 -Wformat -Wformat-security '
-           '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-           '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
-           '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector-strong '
-           '--param=ssp-buffer-size=4 -Wformat -Wformat-security '
-           '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-           '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
-           '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector-strong '
-           '--param=ssp-buffer-size=4 -Wformat -Wformat-security '
-           '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-           '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -pipe -fexceptions '
+           '--param=ssp-buffer-size=4 -D_FILE_OFFSET_BITS=64 -O2 '
+           '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+           '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 -fstack-protector-strong '
+           '-Wall -Wformat -Wformat-security  -fmessage-length=0 '
+           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -g '
+           '-pipe -fexceptions --param=ssp-buffer-size=4 '
+           '-D_FILE_OFFSET_BITS=64 -O2 '
+           '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+           '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 -fstack-protector-strong '
+           '-Wall -Wformat -Wformat-security  -fmessage-length=0 '
+           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -g '
+           '-pipe -fexceptions --param=ssp-buffer-size=4 '
+           '-D_FILE_OFFSET_BITS=64 -O2 '
+           '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+           '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 -fstack-protector-strong '
+           '-Wall -Wformat -Wformat-security  -fmessage-length=0 '
+           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                     '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                     '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
-                     '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
-                     '-mfpu=neon -mthumb -Wno-psabi',
+ 'CONFIGURE_CFLAGS': '-g -pipe -fexceptions --param=ssp-buffer-size=4 '
+                     '-D_FILE_OFFSET_BITS=64 -O2 '
+                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+                     '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 '
+                     '-fstack-protector-strong -Wall -Wformat '
+                     '-Wformat-security  -fmessage-length=0 -march=armv7-a '
+                     '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
+                            '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '',
+ 'CONFIGURE_LDFLAGS': '-Wl,--as-needed -specs=/usr/lib/rpm/aurora/pie-pic-ld '
+                      '-Wl,-z,relro,-z,now',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--libdir=/usr/lib' '--mandir=/usr/share/man' "
                 "'--docdir=/usr/share/doc/python' '--enable-ipv6' "
                 "'--enable-shared' '--with-ensurepip=no' "
-                "'--with-dbmliborder=bdb' '--with-system-ffi=yes' 'CFLAGS=-O2 "
-                '-g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                '-fstack-protector-strong --param=ssp-buffer-size=4 -Wformat '
-                '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
-                '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb '
-                "-Wno-psabi' "
+                "'--with-dbmliborder=bdb' '--with-system-ffi=yes' 'CFLAGS=-g "
+                '-pipe -fexceptions --param=ssp-buffer-size=4 '
+                '-D_FILE_OFFSET_BITS=64 -O2 '
+                '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+                '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 '
+                '-fstack-protector-strong -Wall -Wformat -Wformat-security  '
+                '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard -mfpu=neon '
+                "-mthumb -Wno-psabi' 'LDFLAGS=-Wl,--as-needed "
+                "-specs=/usr/lib/rpm/aurora/pie-pic-ld -Wl,-z,relro,-z,now' "
                 "'PKG_CONFIG_PATH=:/usr/lib/pkgconfig:/usr/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.8',
@@ -67,7 +82,7 @@ build_time_vars = {'ABIFLAGS': '',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
- 'CXX': 'g++ -pthread',
+ 'CXX': 'g++',
  'DESTDIRS': '/usr /usr/lib /usr/lib/python3.8 /usr/lib/python3.8/lib-dynload',
  'DESTLIB': '/usr/lib/python3.8',
  'DESTPATH': '',
@@ -310,8 +325,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
  'HAVE_MEMFD_CREATE': 1,
- 'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
+ 'HAVE_MINIX_CONFIG_H': 0,
  'HAVE_MKDIRAT': 1,
  'HAVE_MKFIFO': 1,
  'HAVE_MKFIFOAT': 1,
@@ -424,13 +439,14 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STAT_TV_NSEC2': 0,
  'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
+ 'HAVE_STDIO_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
  'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
- 'HAVE_STRLCPY': 0,
+ 'HAVE_STRLCPY': 1,
  'HAVE_STROPTS_H': 0,
  'HAVE_STRSIGNAL': 1,
  'HAVE_STRUCT_PASSWD_PW_GECOS': 1,
@@ -528,7 +544,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'armv7l-unknown-linux-gnueabihf',
+ 'HOST_GNU_TYPE': 'armv7l-unknown-linux-gnueabi',
  'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.8 '
                    '/usr/include/python3.8',
  'INCLUDEDIR': '/usr/include',
@@ -541,12 +557,17 @@ build_time_vars = {'ABIFLAGS': '',
  'INSTSONAME': 'libpython3.8.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '',
+ 'LDCXXSHARED': 'g++ -shared',
+ 'LDFLAGS': '-Wl,--as-needed -specs=/usr/lib/rpm/aurora/pie-pic-ld '
+            '-Wl,-z,relro,-z,now -Wl,--as-needed '
+            '-specs=/usr/lib/rpm/aurora/pie-pic-ld -Wl,-z,relro,-z,now',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.8.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared',
+ 'LDSHARED': 'gcc -shared -Wl,--as-needed '
+             '-specs=/usr/lib/rpm/aurora/pie-pic-ld -Wl,-z,relro,-z,now '
+             '-Wl,--as-needed -specs=/usr/lib/rpm/aurora/pie-pic-ld '
+             '-Wl,-z,relro,-z,now',
  'LDVERSION': '3.8',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.8',
@@ -561,9 +582,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBRARY': 'libpython3.8.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
+ 'LIBS': '-lcrypt -ldl  -lm',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
- 'LINKCC': 'gcc -pthread',
+ 'LINKCC': 'gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
@@ -576,7 +597,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '/usr/lib/python3.8',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'gcc -pthread',
+ 'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
@@ -610,10 +631,11 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DNDEBUG -O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-        '-fstack-protector-strong --param=ssp-buffer-size=4 -Wformat '
-        '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
-        '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
+ 'OPT': '-DNDEBUG -g -pipe -fexceptions --param=ssp-buffer-size=4 '
+        '-D_FILE_OFFSET_BITS=64 -O2 -Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+        '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 -fstack-protector-strong -Wall '
+        '-Wformat -Wformat-security  -fmessage-length=0 -march=armv7-a '
+        '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -643,94 +665,119 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_FOR_REGEN': 'python3.8',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                             '-g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 '
-                             '-fexceptions -fstack-protector-strong '
-                             '--param=ssp-buffer-size=4 -Wformat '
-                             '-Wformat-security -Wl,-z,relro,-z,now '
-                             '-fmessage-length=0 -march=armv7-a '
-                             '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
-                             '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 '
-                             '-fexceptions -fstack-protector-strong '
-                             '--param=ssp-buffer-size=4 -Wformat '
-                             '-Wformat-security -Wl,-z,relro,-z,now '
-                             '-fmessage-length=0 -march=armv7-a '
-                             '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
-                             '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 '
-                             '-fexceptions -fstack-protector-strong '
-                             '--param=ssp-buffer-size=4 -Wformat '
-                             '-Wformat-security -Wl,-z,relro,-z,now '
-                             '-fmessage-length=0 -march=armv7-a '
-                             '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
-                             '-std=c99 -Wextra -Wno-unused-result '
-                             '-Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
+                             '-pipe -fexceptions --param=ssp-buffer-size=4 '
+                             '-D_FILE_OFFSET_BITS=64 -O2 '
+                             '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+                             '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 '
+                             '-fstack-protector-strong -Wall -Wformat '
+                             '-Wformat-security  -fmessage-length=0 '
+                             '-march=armv7-a -mfloat-abi=hard -mfpu=neon '
+                             '-mthumb -Wno-psabi -g -pipe -fexceptions '
+                             '--param=ssp-buffer-size=4 -D_FILE_OFFSET_BITS=64 '
+                             '-O2 -Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+                             '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 '
+                             '-fstack-protector-strong -Wall -Wformat '
+                             '-Wformat-security  -fmessage-length=0 '
+                             '-march=armv7-a -mfloat-abi=hard -mfpu=neon '
+                             '-mthumb -Wno-psabi -g -pipe -fexceptions '
+                             '--param=ssp-buffer-size=4 -D_FILE_OFFSET_BITS=64 '
+                             '-O2 -Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+                             '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 '
+                             '-fstack-protector-strong -Wall -Wformat '
+                             '-Wformat-security  -fmessage-length=0 '
+                             '-march=armv7-a -mfloat-abi=hard -mfpu=neon '
+                             '-mthumb -Wno-psabi -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
+                             '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration  '
                              '-I./Include/internal -I. -I./Include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -g -pipe -Wall '
-              '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector-strong '
-              '--param=ssp-buffer-size=4 -Wformat -Wformat-security '
-              '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-              '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe '
-              '-Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-              '-fstack-protector-strong --param=ssp-buffer-size=4 -Wformat '
-              '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -pipe '
+              '-fexceptions --param=ssp-buffer-size=4 -D_FILE_OFFSET_BITS=64 '
+              '-O2 -Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+              '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 -fstack-protector-strong '
+              '-Wall -Wformat -Wformat-security  -fmessage-length=0 '
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
-              '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-              '-fstack-protector-strong --param=ssp-buffer-size=4 -Wformat '
-              '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
+              '-g -pipe -fexceptions --param=ssp-buffer-size=4 '
+              '-D_FILE_OFFSET_BITS=64 -O2 '
+              '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+              '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 -fstack-protector-strong '
+              '-Wall -Wformat -Wformat-security  -fmessage-length=0 '
+              '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
+              '-g -pipe -fexceptions --param=ssp-buffer-size=4 '
+              '-D_FILE_OFFSET_BITS=64 -O2 '
+              '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+              '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 -fstack-protector-strong '
+              '-Wall -Wformat -Wformat-security  -fmessage-length=0 '
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration  '
                      '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -g -pipe '
-                   '-Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                   '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                   '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -pipe '
+                   '-fexceptions --param=ssp-buffer-size=4 '
+                   '-D_FILE_OFFSET_BITS=64 -O2 '
+                   '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+                   '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 '
+                   '-fstack-protector-strong -Wall -Wformat -Wformat-security  '
                    '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
-                   '-mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                   '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                   '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
+                   '-mfpu=neon -mthumb -Wno-psabi -g -pipe -fexceptions '
+                   '--param=ssp-buffer-size=4 -D_FILE_OFFSET_BITS=64 -O2 '
+                   '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+                   '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 '
+                   '-fstack-protector-strong -Wall -Wformat -Wformat-security  '
                    '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
-                   '-mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                   '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                   '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
+                   '-mfpu=neon -mthumb -Wno-psabi -g -pipe -fexceptions '
+                   '--param=ssp-buffer-size=4 -D_FILE_OFFSET_BITS=64 -O2 '
+                   '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+                   '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 '
+                   '-fstack-protector-strong -Wall -Wformat -Wformat-security  '
                    '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
                    '-mfpu=neon -mthumb -Wno-psabi -std=c99 -Wextra '
                    '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration  '
                    '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '',
+ 'PY_CORE_LDFLAGS': '-Wl,--as-needed -specs=/usr/lib/rpm/aurora/pie-pic-ld '
+                    '-Wl,-z,relro,-z,now -Wl,--as-needed '
+                    '-specs=/usr/lib/rpm/aurora/pie-pic-ld -Wl,-z,relro,-z,now',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '',
+ 'PY_LDFLAGS': '-Wl,--as-needed -specs=/usr/lib/rpm/aurora/pie-pic-ld '
+               '-Wl,-z,relro,-z,now -Wl,--as-needed '
+               '-specs=/usr/lib/rpm/aurora/pie-pic-ld -Wl,-z,relro,-z,now',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -g '
-                        '-pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                        '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                        '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
-                        '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
-                        '-mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
-                        '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                        '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                        '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
-                        '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
-                        '-mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
-                        '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                        '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                        '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
-                        '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
-                        '-mfpu=neon -mthumb -Wno-psabi -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -pipe '
+                        '-fexceptions --param=ssp-buffer-size=4 '
+                        '-D_FILE_OFFSET_BITS=64 -O2 '
+                        '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+                        '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 '
+                        '-fstack-protector-strong -Wall -Wformat '
+                        '-Wformat-security  -fmessage-length=0 -march=armv7-a '
+                        '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -g '
+                        '-pipe -fexceptions --param=ssp-buffer-size=4 '
+                        '-D_FILE_OFFSET_BITS=64 -O2 '
+                        '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+                        '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 '
+                        '-fstack-protector-strong -Wall -Wformat '
+                        '-Wformat-security  -fmessage-length=0 -march=armv7-a '
+                        '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -g '
+                        '-pipe -fexceptions --param=ssp-buffer-size=4 '
+                        '-D_FILE_OFFSET_BITS=64 -O2 '
+                        '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=2 '
+                        '-specs=/usr/lib/rpm/aurora/pie-pic-cc1 '
+                        '-fstack-protector-strong -Wall -Wformat '
+                        '-Wformat-security  -fmessage-length=0 -march=armv7-a '
+                        '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
+                        '-std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration  '
                         '-I./Include/internal -I. -I./Include -fPIC',
  'Py_DEBUG': 0,
@@ -746,9 +793,9 @@ build_time_vars = {'ABIFLAGS': '',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
+ 'SHLIBS': '-lcrypt -ldl  -lm',
  'SHLIB_SUFFIX': '.so',
- 'SHM_NEEDS_LIBRT': 1,
+ 'SHM_NEEDS_LIBRT': 0,
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
